<?php

/**
 * Module: Parallax
 *
 * @author 		SpyroSol
 * @category 	SpyropressBuilderModules
 * @package 	Spyropress
 */

global $parallax_speed;
$parallax_speed = 5;
use Abraham\TwitterOAuth\TwitterOAuth;

class Spyropress_Module_Parallax extends SpyropressBuilderModule {

    public function __construct() {

        $this->path = dirname( __FILE__ );

        // Widget variable settings
        $this->description = __( 'Create parallax in differnet style.', 'spyropress' );
        $this->id_base = 'parallax';
        $this->name = __( 'Parallax Area', 'spyropress' );

        // Templates
        $this->templates['twitter'] = array(
            'label' => __( 'Twitter', 'spyropress' ),
            'view' => 'twitter.php'
        );

        // Fields
        $this->fields = array(

            array(
                'label' => __( 'Style', 'spyropress' ),
                'id' => 'style',
                'type' => 'select',
                'class' => 'enable_changer section-full',
                'options' => $this->get_option_templates()
            ),

            array(
                'label' => __( 'Background Height', 'spyropress' ),
                'id' => 'bg_height',
                'type' => 'range_slider',
                'max' => 600,
                'min' => 200,
                'std' => 330
            ),

            array(
                'label' => __( 'Content', 'spyropress' ),
                'id' => 'content',
                'type' => 'textarea',
                'rows' => 6
            ),

            array(
                'label' => __( 'Background', 'spyropress' ),
                'id' => 'image',
                'type' => 'upload'
            ),

            array(
                'label' => __( 'Twitter Count', 'spyropress' ),
                'id' => 'twitter_counts',
                'class' => 'section-full style twitter',
                'type' => 'range_slider'
            )
        );

        $this->create_widget();
    }

    function widget( $args, $instance ) {

        global $parallax_speed;
        $speed = $parallax_speed;
        $parallax_speed--;
        if( 0 == $parallax_speed )
            $parallax_speed = 5;

        $speed = $speed / 10;

        // extracting info
        $style = '';
        $bg_height = 330;
        extract( $args ); extract( spyropress_clean_array( $instance ) );
        // get view to render
        include $this->get_view( $style );
    }

    function get_tweets( $username = '', $count = false ) {
    	$defaults = array(
	        'lang' => substr( strtoupper( get_locale() ), 0, 2 ),
	        'post_count' => $count ? $count : 10,
	        'username' => $username ? $username : get_setting( 'twitter_username' ),
	        'consumer_key' => get_setting( 'consumer_key' ),
	        'consumer_secret' => get_setting( 'consumer_secret' ),
	        'access_token' => get_setting( 'access_token' ),
	        'access_token_secret' => get_setting( 'access_token_secret' )
	    );
	    extract( $defaults );

	    $key = '_spyropress_' . $username . '_tweets_' . $post_count;

	    if( ! $consumer_key || ! $consumer_secret || ! $access_token || ! $access_token_secret ) {
	        echo 'No oAuth setting provided.';
	        exit;
	    }

	    $tweets = array();
	    if( false === ( $tweets = get_transient( $key ) ) ) {

	        require_once 'twitteroauth/autoload.php';
	        $twitterConnection = new TwitterOAuth( $consumer_key, $consumer_secret, $access_token, $access_token_secret );

	    	$tweets = $twitterConnection->get(
	    			  'statuses/user_timeline',
	    			  array(
	    			    'screen_name'     => $username,
	    			    'count'           => $post_count,
	    			    //'exclude_replies' => true
	    			  )
	    	);

	    	if($twitterConnection->getLastHttpCode() != 200) {
	    		$tweets = get_transient( $key );
	    	}

	        // Cache
	        set_transient( $key, $tweets, spyropress_get_seconds( 0.1 ) );
	    }
	    
	    return $tweets;
    }

    function convert_links( $status, $targetBlank=true, $linkMaxLen=250 ) {

		// the target
		$target = $targetBlank ? " target=\"_blank\" " : "";

		// convert link to url
		$status = preg_replace( '/\b(http|https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[A-Z0-9+&@#\/%=~_|]/i', '<a href="\0" target="_blank">\0</a>', $status );

		// convert @ to follow
		$status = preg_replace( "/(@([_a-z0-9\-]+))/i","<a href=\"http://twitter.com/$2\" title=\"Follow $2\" target=\"_blank\" >$1</a>",$status );

		// convert # to search
		$status = preg_replace( "/(#([_a-z0-9\-]+))/i","<a href=\"https://twitter.com/search?q=$2\" title=\"Search $1\" target=\"_blank\" >$1</a>",$status );

		return $status;
	}

}
spyropress_builder_register_module( 'Spyropress_Module_Parallax' );