<?php

/**
 * Gallery Component
 * 
 * @package		SpyroPress
 * @category	Components
 */

class SpyropressGallery extends SpyropressComponent {

    private $path;
    
    function __construct() {

        $this->path = dirname(__FILE__);
        add_action( 'spyropress_register_taxonomy', array( $this, 'register' ) );
        add_filter( 'builder_include_modules', array( $this, 'register_module' ) );
    }

    function register() {

        // Init Post Type
        $args = array(
            'supports' => array( 'title' )
        );
        $post = new SpyropressCustomPostType( __( 'Gallery', 'spyropress' ), '', $args );
        $post->add_taxonomy( __( 'Category', 'spyropress' ), 'gallery_cats', '', array( 'hierarchical' => true ) );
        
        // Add Meta Boxes
        $meta_fields['gallery'] = array(
            array(
                'label' => __( 'Gallery', 'spyropress' ),
                'type' => 'heading',
                'slug' => 'gallery'
            ),
            
            array(
                'label' => __( 'Content Type', 'spyropress' ),
                'id' => 'content_type',
                'type' => 'select',
                'class' => 'enable_changer',
                'options' => array(
                    'image' => __( 'Picture', 'spyropress' ),
                    'video' => __( 'Video', 'spyropress' )
                ),
                'std' => 'image'
            ),
    
            array(
                'label' => __( 'Picture', 'spyropress' ),
                'id' => 'image',
                'type' => 'upload'
            ),
    
            array(
                'label' => __( 'Video URL', 'spyropress' ),
                'class' => 'content_type video',
                'id' => 'video_url',
                'type' => 'text'
            )
        );
        
        $post->add_meta_box( 'gallery_content', 'Content', $meta_fields, '_gallery_content', false );
    }
    
    function register_widget( $widgets ) {
        
        $widgets[] = $this->path . '/widget';
        
        return $widgets;
    }
    
    function register_module( $modules ) {

        $modules[] = $this->path . '/module/module.php';

        return $modules;
    }
}

/**
 * Init the Component
 */
new SpyropressGallery();