<?php

/**
 * Portfolio Component
 * 
 * @package		SpyroPress
 * @category	Components
 */

class SpyropressPortfolio extends SpyropressComponent {

    private $path;
    
    function __construct() {

        $this->path = dirname(__FILE__);
        add_action( 'spyropress_register_taxonomy', array( $this, 'register' ) );
        add_filter( 'builder_include_modules', array( $this, 'register_module' ) );
    }

    function register() {

        // Init Post Type
        $args = array(
            'supports'      => array( 'title', 'editor', 'thumbnail' ),
            'has_archive'   => false,
            'exclude_from_search' => true,
            'rewrite' => array( 'slug' => get_setting( 'portfolio-slug', 'portfolio' ) )
        );
        $post = new SpyropressCustomPostType( __( 'Portfolio', 'spyropress' ), '', $args );
        $post->add_taxonomy( __( 'Tags', 'spyropress' ), 'portfolio_tags' );
        
        // Add Meta Boxes
        $meta_fields['portfolio'] = array(
            array(
                'label' => __( 'Portfolio', 'spyropress' ),
                'type' => 'heading',
                'slug' => 'portfolio'
            ),
            
            array(
                'label' => __( 'Client', 'spyropress' ),
                'id' => 'client',
                'type' => 'text'
            ),
    
            array(
                'label' => __( 'Release Date', 'spyropress' ),
                'id' => 'date',
                'type' => 'datepicker'
            ),
    
            array(
                'label' => __( 'Project URL', 'spyropress' ),
                'id' => 'project_url',
                'type' => 'text'
            ),
            
            array(
                'label' => __( 'Client Logo', 'spyropress' ),
                'id' => 'client_logo',
                'type' => 'upload'
            ),
            
            array(
                'label' => __( 'Portfolio Previews', 'spyropress' ),
                'id' => 'previews',
                'type' => 'gallery'
            )
        );
        
        $post->add_meta_box( 'portfolio', __( 'Portfolio Details', 'spyropress' ), $meta_fields, '_portfolio_details', false );
    }
    
    function register_widget( $widgets ) {
        
        $widgets[] = $this->path . '/widget';
        
        return $widgets;
    }
    
    function register_module( $modules ) {

        $modules[] = $this->path . '/module/module.php';

        return $modules;
    }
}

/**
 * Init the Component
 */
new SpyropressPortfolio();